==> agiledataecho-0.0.2.0020-sources.jar: docker/shell.sh <==
#!/bin/sh
sed -i "s#@profile_active@#$profile_active#g" /usr/local/agiledataecho/application.yml
sed -i "s#@athena_logger_enable@#$athena_logger_enable#g" /usr/local/agiledataecho/application.yml
#sed -i "s#@lmc_endpoint@#$lmc_endpoint#g" /usr/local/agiledataecho/logback-spring.xml

sed -i "s#@redis_host@#$redis_host#g" /usr/local/agiledataecho/application.yml
sed -i "s#@redis_port@#$redis_port#g" /usr/local/agiledataecho/application.yml
sed -i "s#@redis_password@#$redis_password#g" /usr/local/agiledataecho/application.yml

sed -i "s#@mongodb_database@#$mongodb_echo_database#g" /usr/local/agiledataecho/application.yml
sed -i "s#@mongodb_echo_agileDataPagebase@#$mongodb_echo_agileDataPagebase#g" /usr/local/agiledataecho/application.yml


sed -i "s#@dbServer@#$dbServer#g" /usr/local/agiledataecho/application.yml
sed -i "s#@dbName@#$dbName#g" /usr/local/agiledataecho/application.yml
sed -i "s#@dbUser@#$dbUser#g" /usr/local/agiledataecho/application.yml
sed -i "s#@dbPassword@#$dbPassword#g" /usr/local/agiledataecho/application.yml

sed -i "s#@rabbitmq_host@#$rabbitmq_host#g" /usr/local/agiledataecho/application.yml
sed -i "s#@rabbitmq_port@#$rabbitmq_port#g" /usr/local/agiledataecho/application.yml

sed -i "s#@rabbitmq_username@#$rabbitmq_username#g" /usr/local/agiledataecho/application.yml
sed -i "s#@rabbitmq_password@#$rabbitmq_password#g" /usr/local/agiledataecho/application.yml
sed -i "s#@rabbitmq_virtual_host@#$rabbitmq_virtual_host#g" /usr/local/agiledataecho/application.yml

sed -i "s#@iam_uri@#$iam_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@iam_bossUri@#$iam_bossUri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@iam_cacUri@#$iam_cacUri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@themeMap_uri@#$themeMap_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@themeMap_rootUri@#$themeMap_rootUri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@themeMap_dataMapUri@#$themeMap_dataMapUri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@themeMap_knowledgeGraphUri@#$themeMap_knowledgeGraphUri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@themeMap_supportPerson@#$themeMap_supportPerson#g" /usr/local/agiledataecho/application.yml
sed -i "s#@bpm_uri@#$bpm_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@uibot_uri@#$uibot_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@eoc_uri@#$eoc_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@im_uri@#$im_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@taskEngine_uri@#$taskEngine_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@ptm_uri@#$ptm_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@abt_uri@#$abt_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@aim_uri@#$aim_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@aam_uri@#$aam_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@ade_uri@#$ade_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@adt_uri@#$adt_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@semc_uri@#$semc_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@chatBI_uri@#$chatBI_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@chatBI_strategy@#$chatBI_strategy#g" /usr/local/agiledataecho/application.yml
sed -i "s#@chatBI_gptModel@#$chatBI_gptModel#g" /usr/local/agiledataecho/application.yml
sed -i "s#@language@#$language#g" /usr/local/agiledataecho/application.yml
sed -i "s#@gmc_uri@#gmc_uri#g" /usr/local/agiledataecho/application.yml

sed -i "s#@apollo_cluster@#$apollo_cluster#g" /usr/local/agiledataecho/application.yml
sed -i "s#@apollo_meta@#$apollo_meta#g" /usr/local/agiledataecho/application.yml
sed -i "s#@apollo_namespaces@#$apollo_namespaces#g" /usr/local/agiledataecho/application.yml
sed -i "s#@loadbalance_enable@#$loadbalance_enable#g" /usr/local/agiledataecho/application.yml
sed -i "s#@nacos_serverAddr@#$nacos_serverAddr#g" /usr/local/agiledataecho/application.yml

sed -i "s#@xxl_job_admin_addresses@#$xxl_job_admin_addresses#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_accessToken@#$xxl_job_accessToken#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_executor_appname@#$xxl_job_executor_appname#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_executor_address@#$xxl_job_executor_address#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_executor_ip@#$xxl_job_executor_ip#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_executor_port@#$xxl_job_executor_port#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_executor_logpath@#$xxl_job_executor_logpath#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_executor_logretentiondays@#$xxl_job_executor_logretentiondays#g" /usr/local/agiledataecho/application.yml

#java -Djava.security.egd=file:/dev/./urandom -Xms500m -Xmx500m -jar agiledataecho-0.0.1.jar

if  "$dongtai"  = "ture" ;  then
    export dongtai="-javaagent:/usr/local/agiledataecho/dongtai/dongtai-agent.jar -Dproject.create=true -Dproject.name=agiledataecho -Dproject.version=agiledataecho.$(date "+%Y%m%d") -Diast.engine.delay.time=60"
fi


JAVA_OPTS="${java_opts}"
if [ -z "$JAVA_OPTS" ]; then
  JAVA_OPTS="-Xms500m -Xmx500m"
fi

export apollo_opts="-Denv=${apollo_env}"

export jar_name=agiledataecho-0.0.2.0020.jar
if test -z "$pinpoint_appname";
then
    if [ "${profile_active}" = "dev" ]; then
        java $dongtai -Djava.security.egd=file:/dev/./urandom $JAVA_OPTS -XX:+HeapDumpOnOutOfMemoryError -XX:HeapDumpPath=/usr/local/agiledataecho/.logs -XX:+PrintGCDateStamps -XX:MetaspaceSize=256m -XX:MaxMetaspaceSize=256m -XX:+PrintGCDetails -Xloggc:/usr/local/agiledataecho/.logs/gc.log -XX:+UseGCLogFileRotation -XX:NumberOfGCLogFiles=10 -XX:GCLogFileSize=100M -agentlib:jdwp=transport=dt_socket,server=y,suspend=n,address=20019 -jar $jar_name
      else
        java $dongtai -Djava.security.egd=file:/dev/./urandom $JAVA_OPTS -jar $jar_name
      fi
else
    export AGENT_PATH=/usr/local/agiledataecho/agent_pinpoint/pinpoint-bootstrap.jar
    export AGENT_NAME=$pinpoint_appname
    sed -i "s/profiler\.transport\.grpc\.collector\.ip=.*/profiler\.transport\.grpc\.collector\.ip=$collector_ip/g" agent_pinpoint/profiles/release/pinpoint.config
    sed -i "s/profiler\.collector\.ip=.*/profiler\.collector\.ip=$collector_ip/g" agent_pinpoint/profiles/release/pinpoint.config

    #get AGENT_ID
    nameSize=${#HOSTNAME}
    if [ $nameSize -ge 5 ] ; then
       export AGENT_ID_SUFFIX=${HOSTNAME:0-5}
    else
       export AGENT_ID_SUFFIX=$HOSTNAME
    fi

    if test -n "$AGENT_ID_SUFFIX" ; then
       export AGENT_ID=$pinpoint_id-$AGENT_ID_SUFFIX
    else
       export AGENT_ID=$pinpoint_id
    fi
    export AGENT_OPTS="-javaagent:$AGENT_PATH -Dpinpoint.agentId=$AGENT_ID -Dpinpoint.applicationName=$AGENT_NAME"
    chmod 777 /usr/local/agiledataecho/agent_pinpoint
    java $apollo_opts $dongtai $AGENT_OPTS -Djava.security.egd=file:/dev/./urandom $JAVA_OPTS -XX:+HeapDumpOnOutOfMemoryError -XX:HeapDumpPath=/usr/local/agiledataecho/.logs -XX:+PrintGCDateStamps -XX:MetaspaceSize=256m -XX:MaxMetaspaceSize=256m -XX:+PrintGCDetails -Xloggc:/usr/local/agiledataecho/.logs/gc.log -XX:+UseGCLogFileRotation -XX:NumberOfGCLogFiles=10 -XX:GCLogFileSize=100M -jar $jar_name
fi

==> agiledataecho-0.0.2.0022-sources.jar: docker/shell.sh <==
#!/bin/sh
sed -i "s#@profile_active@#$profile_active#g" /usr/local/agiledataecho/application.yml
sed -i "s#@athena_logger_enable@#$athena_logger_enable#g" /usr/local/agiledataecho/application.yml
#sed -i "s#@lmc_log_endpoint@#$lmc_log_endpoint#g" /usr/local/agiledataecho/logback-spring.xml

sed -i "s#@redis_host@#$redis_host#g" /usr/local/agiledataecho/application.yml
sed -i "s#@redis_port@#$redis_port#g" /usr/local/agiledataecho/application.yml
sed -i "s#@redis_password@#$redis_password#g" /usr/local/agiledataecho/application.yml

sed -i "s#@mongodb_database@#$mongodb_echo_database#g" /usr/local/agiledataecho/application.yml
sed -i "s#@mongodb_echo_agileDataPagebase@#$mongodb_echo_agileDataPagebase#g" /usr/local/agiledataecho/application.yml


sed -i "s#@dbServer@#$dbServer#g" /usr/local/agiledataecho/application.yml
sed -i "s#@dbName@#$dbName#g" /usr/local/agiledataecho/application.yml
sed -i "s#@dbUser@#$dbUser#g" /usr/local/agiledataecho/application.yml
sed -i "s#@dbPassword@#$dbPassword#g" /usr/local/agiledataecho/application.yml

sed -i "s#@rabbitmq_host@#$rabbitmq_host#g" /usr/local/agiledataecho/application.yml
sed -i "s#@rabbitmq_port@#$rabbitmq_port#g" /usr/local/agiledataecho/application.yml

sed -i "s#@rabbitmq_username@#$rabbitmq_username#g" /usr/local/agiledataecho/application.yml
sed -i "s#@rabbitmq_password@#$rabbitmq_password#g" /usr/local/agiledataecho/application.yml
sed -i "s#@rabbitmq_virtual_host@#$rabbitmq_virtual_host#g" /usr/local/agiledataecho/application.yml

sed -i "s#@iam_uri@#$iam_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@iam_bossUri@#$iam_bossUri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@iam_cacUri@#$iam_cacUri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@themeMap_uri@#$themeMap_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@themeMap_rootUri@#$themeMap_rootUri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@themeMap_dataMapUri@#$themeMap_dataMapUri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@themeMap_knowledgeGraphUri@#$themeMap_knowledgeGraphUri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@themeMap_supportPerson@#$themeMap_supportPerson#g" /usr/local/agiledataecho/application.yml
sed -i "s#@bpm_uri@#$bpm_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@uibot_uri@#$uibot_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@eoc_uri@#$eoc_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@im_uri@#$im_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@taskEngine_uri@#$taskEngine_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@ptm_uri@#$ptm_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@abt_uri@#$abt_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@aim_uri@#$aim_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@aam_uri@#$aam_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@ade_uri@#$ade_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@adt_uri@#$adt_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@semc_uri@#$semc_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@chatBI_uri@#$chatBI_uri#g" /usr/local/agiledataecho/application.yml
sed -i "s#@chatBI_strategy@#$chatBI_strategy#g" /usr/local/agiledataecho/application.yml
sed -i "s#@chatBI_gptModel@#$chatBI_gptModel#g" /usr/local/agiledataecho/application.yml
sed -i "s#@language@#$language#g" /usr/local/agiledataecho/application.yml
sed -i "s#@gmc_uri@#gmc_uri#g" /usr/local/agiledataecho/application.yml

sed -i "s#@apollo_cluster@#$apollo_cluster#g" /usr/local/agiledataecho/application.yml
sed -i "s#@apollo_meta@#$apollo_meta#g" /usr/local/agiledataecho/application.yml
sed -i "s#@apollo_namespaces@#$apollo_namespaces#g" /usr/local/agiledataecho/application.yml
sed -i "s#@loadbalance_enable@#$loadbalance_enable#g" /usr/local/agiledataecho/application.yml
sed -i "s#@nacos_serverAddr@#$nacos_serverAddr#g" /usr/local/agiledataecho/application.yml

sed -i "s#@xxl_job_admin_addresses@#$xxl_job_admin_addresses#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_accessToken@#$xxl_job_accessToken#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_executor_appname@#$xxl_job_executor_appname#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_executor_address@#$xxl_job_executor_address#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_executor_ip@#$xxl_job_executor_ip#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_executor_port@#$xxl_job_executor_port#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_executor_logpath@#$xxl_job_executor_logpath#g" /usr/local/agiledataecho/application.yml
sed -i "s#@xxl_job_executor_logretentiondays@#$xxl_job_executor_logretentiondays#g" /usr/local/agiledataecho/application.yml

#java -Djava.security.egd=file:/dev/./urandom -Xms500m -Xmx500m -jar agiledataecho-0.0.1.jar

if  "$dongtai"  = "ture" ;  then
    export dongtai="-javaagent:/usr/local/agiledataecho/dongtai/dongtai-agent.jar -Dproject.create=true -Dproject.name=agiledataecho -Dproject.version=agiledataecho.$(date "+%Y%m%d") -Diast.engine.delay.time=60"
fi


JAVA_OPTS="${java_opts}"
if [ -z "$JAVA_OPTS" ]; then
  JAVA_OPTS="-Xms500m -Xmx500m"
fi

export apollo_opts="-Denv=${apollo_env}"

export jar_name=agiledataecho-0.0.2.0022.jar
if test -z "$pinpoint_appname";
then
    if [ "${profile_active}" = "dev" ]; then
        java $dongtai -Djava.security.egd=file:/dev/./urandom $JAVA_OPTS -XX:+HeapDumpOnOutOfMemoryError -XX:HeapDumpPath=/usr/local/agiledataecho/.logs -XX:+PrintGCDateStamps -XX:MetaspaceSize=256m -XX:MaxMetaspaceSize=256m -XX:+PrintGCDetails -Xloggc:/usr/local/agiledataecho/.logs/gc.log -XX:+UseGCLogFileRotation -XX:NumberOfGCLogFiles=10 -XX:GCLogFileSize=100M -agentlib:jdwp=transport=dt_socket,server=y,suspend=n,address=20019 -jar $jar_name
      else
        java $dongtai -Djava.security.egd=file:/dev/./urandom $JAVA_OPTS -jar $jar_name
      fi
else
    export AGENT_PATH=/usr/local/agiledataecho/agent_pinpoint/pinpoint-bootstrap.jar
    export AGENT_NAME=$pinpoint_appname
    sed -i "s/profiler\.transport\.grpc\.collector\.ip=.*/profiler\.transport\.grpc\.collector\.ip=$collector_ip/g" agent_pinpoint/profiles/release/pinpoint.config
    sed -i "s/profiler\.collector\.ip=.*/profiler\.collector\.ip=$collector_ip/g" agent_pinpoint/profiles/release/pinpoint.config

    #get AGENT_ID
    nameSize=${#HOSTNAME}
    if [ $nameSize -ge 5 ] ; then
       export AGENT_ID_SUFFIX=${HOSTNAME:0-5}
    else
       export AGENT_ID_SUFFIX=$HOSTNAME
    fi

    if test -n "$AGENT_ID_SUFFIX" ; then
       export AGENT_ID=$pinpoint_id-$AGENT_ID_SUFFIX
    else
       export AGENT_ID=$pinpoint_id
    fi
    export AGENT_OPTS="-javaagent:$AGENT_PATH -Dpinpoint.agentId=$AGENT_ID -Dpinpoint.applicationName=$AGENT_NAME"
    chmod 777 /usr/local/agiledataecho/agent_pinpoint
    java $apollo_opts $dongtai $AGENT_OPTS -Djava.security.egd=file:/dev/./urandom $JAVA_OPTS -XX:+HeapDumpOnOutOfMemoryError -XX:HeapDumpPath=/usr/local/agiledataecho/.logs -XX:+PrintGCDateStamps -XX:MetaspaceSize=256m -XX:MaxMetaspaceSize=256m -XX:+PrintGCDetails -Xloggc:/usr/local/agiledataecho/.logs/gc.log -XX:+UseGCLogFileRotation -XX:NumberOfGCLogFiles=10 -XX:GCLogFileSize=100M -jar $jar_name
fi
